@@ -100,6 +100,9 @@ def install_npm(force, stdout):
         if os.path.exists(node_modules_path):
             shutil.rmtree(node_modules_path, ignore_errors=True)
         call_command("create_package_json")
+        if "SUDO_UID" in os.environ:
+            del os.environ["SUDO_UID"]
+        os.environ["npm_config_unsafe_perm"]="true"
         call(["npm", "install"], cwd=TRANSPILE_CACHE_PATH)
         signals.post_npm_install.send(sender=None)
         npm_install = True
